@@ -34,7 +34,10 @@ def _format_full(annotation: Type[Any], config: Config) -> Optional[str]:
 
     # Only if this is a real class we override sphinx_autodoc_typehints
     if inspect.isclass(annotation) or inspect.isclass(origin):
-        full_name = f"{annotation.__module__}.{annotation.__qualname__}"
+        try:
+            full_name = f"{annotation.__module__}.{annotation.__qualname__}"
+        except AttributeError:
+            full_name = f"{origin.__module__}.{origin.__qualname__}"
         override = elegant_typehints.qualname_overrides.get(full_name)
         role = "exc" if issubclass(annotation_cls, BaseException) else "class"
         if override is not None:
@@ -78,7 +81,7 @@ def _format_terse(annotation: Type[Any], config: Config) -> str:
 
 
 def format_annotation(annotation: Type[Any], config: Config) -> Optional[str]:
-    r"""Generate reStructuredText containing links to the types.
+    """Generate reStructuredText containing links to the types.
 
     Unlike :func:`sphinx_autodoc_typehints.format_annotation`,
     it tries to achieve a simpler style as seen in numeric packages like numpy.
@@ -93,7 +96,7 @@ def format_annotation(annotation: Type[Any], config: Config) -> Optional[str]:
 
     curframe = inspect.currentframe()
     calframe = inspect.getouterframes(curframe, 2)
-    if calframe[2].function == "process_docstring" or (
+    if calframe[2].function in {"process_docstring", "_inject_signature"} or (
         calframe[2].function == "_inject_types_to_docstring"
         and calframe[3].function == "process_docstring"
     ):
