@@ -150,6 +150,13 @@ def test_literal(app):
     assert _format_full(Literal["str", 1, None], app.config) is None
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason="Syntax only available on 3.10+")
+def test_syntax_vs_typing(app):
+    u = eval("int | str")
+    assert _format_terse(u, app.config) == ":py:class:`int` | :py:class:`str`"
+    assert _format_full(u, app.config) is None  # this used to crash
+
+
 def test_qualname_overrides_class(app, _testmod):
     assert _testmod.Class.__module__ == "_testmod"
     assert _format_terse(_testmod.Class, app.config) == ":py:class:`~test.Class`"
@@ -193,7 +200,6 @@ def test_classes_get_added(app, parse):
         # t.NoReturn,
         t.Callable[[int], None],
         # t.ClassVar[t.Any],
-        t.Optional[int],
         t.Tuple[int, str],
         t.Tuple[float, ...],
         t.Union[int, str],
@@ -212,9 +218,6 @@ def test_typing_classes(app, annotation, formatter):
     )
     if formatter is _format_terse and name in {"Union", "Callable"}:
         pytest.skip("Tested elsewhere")
-    args = get_args(annotation)
-    if name == "Union" and len(args) == 2 and type(None) in args:
-        name = "Optional"
     output = formatter(annotation, app.config)
     assert output is None or output.startswith(f":py:data:`typing.{name}")
 
@@ -242,7 +245,7 @@ def test_autodoc(app, _testmod, direc, base, sub):
         out,
     ), out
     assert f'<a class="headerlink" href="#test.{sub}"' in out, out
-    assert re.search(rf"Bases: <code[^>]*><span[^>]*>test\.{base}", out), out
+    assert re.search(rf"Bases: <code[^>]*><span[^>]*>(?:test\.)?{base}", out), out
 
 
 @pytest.mark.skipif(sys.version_info < (3, 7), reason="bpo-34776 only fixed on 3.7+")
@@ -331,9 +334,9 @@ def test_return(process_doc, docstring, return_ann, foo_rendered):
         if not re.match("^:(rtype|param|annotation-(full|terse)):", l)
     ]
     assert lines == [
-        rf":return: foo : {foo_rendered}",
+        f":return: foo : {foo_rendered}",
         "             A foo!",
-        r"         bar : :py:class:`int`",
+        "         bar : :py:class:`int`",
         "             A bar!",
     ]
 
